@@ -17,7 +17,6 @@ use parent qw(Kernel::System::EventHandler);
 use Kernel::System::VariableCheck qw(:all);
 
 our @ObjectDependencies = (
-    'Kernel::System::Cache',
     'Kernel::System::CommunicationChannel',
     'Kernel::System::DB',
     'Kernel::System::DynamicField',
@@ -26,6 +25,8 @@ our @ObjectDependencies = (
     'Kernel::System::Log',
     'Kernel::System::Main',
     'Kernel::System::Ticket::Article',
+
+    #     'Kernel::System::Ticket::Article::Backend::MyBackend',
 );
 
 =head1 NAME
@@ -164,6 +165,7 @@ Create an article. Override this method in your class.
     );
 
 Events:
+
     ArticleCreate
 
 =cut
@@ -185,6 +187,7 @@ Update an article. Override this method in your class.
     );
 
 Events:
+
     ArticleUpdate
 
 =cut
@@ -271,7 +274,7 @@ Returns:
         'Cc'      => 'Test User3 <testuser3@example.com>',
         'Subject' => 'This is a test subject!',
         'Body'    => 'This is a body text!',
-        ...
+        # ...
         },
     ];
 
@@ -422,6 +425,7 @@ Note: Keys C<SenderType>, C<SenderTypeID> and C<IsVisibleForCustomer> are implem
     );
 
 Events:
+
     MetaArticleUpdate
 
 =cut
@@ -624,19 +628,20 @@ Returns article content with dynamic fields.
             ArticleID => 1,
             From      => 'agent@mail.org',
             To        => 'customer@mail.org',
-            ...
+            # ...
         },
     );
 
 Returns:
+
     %Data = (
         TicketID  => 1,
         ArticleID => 1,
         From      => 'agent@mail.org',
         To        => 'customer@mail.org',
-        ...,
+        # ...,
         DynamicField_A  => 'Value A',
-        ...
+        # ...
     );
 
 =cut
