@@ -47,10 +47,21 @@ sub Run {
     );
 
     my @PackageNames = (
-        'Znuny-MarkTicketSeenUnseen',
-        'Znuny4OTRS-MarkTicketSeenUnseen',
+        'Znuny-AdminValidFilter',
+        'Znuny4OTRS-AdminValidFilter',
+        'Znuny-ArticleColors',
+        'Znuny4OTRS-ArticleColors',
         'Znuny-CustomPriorityColor',
         'Znuny4OTRS-CustomPriorityColor',
+        'Znuny-OAuth2ClientCredentialsFlow',
+        'Znuny-DynamicFieldAdminAutoConfig',
+        'Znuny4OTRS-DynamicFieldAdminAutoConfig',
+        'Znuny-MarkTicketSeenUnseen',
+        'Znuny4OTRS-MarkTicketSeenUnseen',
+        'Znuny-Translations',
+        'Znuny4OTRS-Translations',
+        'Znuny-MSGraphMail',
+        'Znuny-BugfixIssue1206',
     );
 
     PACKAGENAME:
